# Primary Authors

- Matias Agustin Mendez (https://github.com/matagus)

# Contributors

 * Jérémy Bethmont
 * Steve Schwarz
 * Milton Mazzarri
 * @chrys
 * @akariv
 * Davide Setti
 * Joeri Poesen
 * @MissFilly
 * @angvp (Angel Velasquez)
 * @jimr (James Rutherford)
 * @jilljenn (Jill-Jênn Via)
 * @eluttine (Elias Luttinen)
